@@ -1,47 +1,14 @@
 package Config::IOD::Document;
 
-our $DATE = '2016-03-02'; # DATE
-our $VERSION = '0.28'; # VERSION
+our $DATE = '2016-03-03'; # DATE
+our $VERSION = '0.29'; # VERSION
 
 use 5.010;
 use strict;
 use warnings;
 #use Carp; # avoided to shave a bit of startup time
 
-use constant +{
-    COL_TYPE => 0,
-
-    COL_B_RAW => 1,
-
-    COL_D_COMMENT_CHAR => 1,
-    COL_D_WS1 => 2,
-    COL_D_WS2 => 3,
-    COL_D_DIRECTIVE => 4,
-    COL_D_WS3 => 5,
-    COL_D_ARGS_RAW => 6,
-    COL_D_NL => 7,
-
-    COL_C_WS1 => 1,
-    COL_C_COMMENT_CHAR => 2,
-    COL_C_COMMENT => 3,
-    COL_C_NL => 4,
-
-    COL_S_WS1 => 1,
-    COL_S_WS2 => 2,
-    COL_S_SECTION => 3,
-    COL_S_WS3 => 4,
-    COL_S_WS4 => 5,
-    COL_S_COMMENT_CHAR => 6,
-    COL_S_COMMENT => 7,
-    COL_S_NL => 8,
-
-    COL_K_WS1 => 1,
-    COL_K_KEY => 2,
-    COL_K_WS2 => 3,
-    COL_K_WS3 => 4,
-    COL_K_VALUE_RAW => 5,
-    COL_K_NL => 6,
-};
+use Config::IOD::Constants qw(:ALL);
 
 sub new {
     my ($class, %attrs) = @_;
@@ -814,7 +781,7 @@ Config::IOD::Document - Represent IOD document
 
 =head1 VERSION
 
-This document describes version 0.28 of Config::IOD::Document (from Perl distribution Config-IOD), released on 2016-03-02.
+This document describes version 0.29 of Config::IOD::Document (from Perl distribution Config-IOD), released on 2016-03-03.
 
 =head1 SYNOPSIS
 
@@ -1016,16 +983,6 @@ If set to 1, will only list the first occurence of each section.
 
 Empty document.
 
-=head2 $doc->get_value($section, $key) => $value
-
-Get value. Values are decoded and section merging is respected, but includes are
-not processed.
-
-Internally, will do a C<dump()> and cache the result so subsequent
-C<get_value()> will avoid re-parsing the whole document. (The cache will
-automatically be discarded is one of document-modifying methods like
-C<delete_section()> is called.)
-
 =head2 $doc->get_directive_before_key($section, $key) => array
 
 Find directive right before a key. Directive must directly precede key line
@@ -1037,10 +994,21 @@ without any blank line, e.g.:
 If found, will return an arrayref containing directive name and arguments.
 Otherwise, will return undef.
 
-=head2 $doc->insert_key([\%opts, ]$section, $key, $value)
+=head2 $doc->get_value($section, $key) => $value
 
-Insert a key named C<$name> with value C<$value> under C<$section>. Die on
-failure.
+Get value. Values are decoded and section merging is respected, but includes are
+not processed.
+
+Internally, will do a C<dump()> and cache the result so subsequent
+C<get_value()> will avoid re-parsing the whole document. (The cache will
+automatically be discarded is one of document-modifying methods like
+C<delete_section()> is called.)
+
+=head2 $doc->insert_key([\%opts, ]$section, $key, $value) => int
+
+Insert a key named C<$name> with value C<$value> under C<$section>. Return line
+number where the key is inserted, or undef if nothing is inserted (e.g. when
+C<ignore> option is set to true). Die on failure.
 
 Options:
 
@@ -1080,7 +1048,8 @@ section. Ignores C<top>.
 =head2 $doc->insert_section([\%opts, ]$name) => int
 
 Insert empty section named C<$name>. Return line number where the section is
-inserted. Die on failure.
+inserted, or undef if nothing is inserted (e.g. when C<ignore> option is set to
+true). Die on failure.
 
 Options:
 
@@ -1105,20 +1074,6 @@ Optional. Insert at this specific line number. Ignores C<top>.
 
 =back
 
-=head2 $doc->list_sections([ \%opts ]) => LIST
-
-List sections in the document, in order of occurrence.
-
-Options:
-
-=over
-
-=item * unique => bool
-
-If set to 1, will only list the first occurrence of each section.
-
-=back
-
 =head2 $doc->list_keys([ \%opts ], $section) => LIST
 
 List keys in the section named <$section>.
@@ -1133,6 +1088,20 @@ If set to 1, will only list the first occurrence of each key.
 
 =back
 
+=head2 $doc->list_sections([ \%opts ]) => LIST
+
+List sections in the document, in order of occurrence.
+
+Options:
+
+=over
+
+=item * unique => bool
+
+If set to 1, will only list the first occurrence of each section.
+
+=back
+
 =head2 $doc->set_value([ \%opts ], $section, $key, $new_value)
 
 Set value of a key.
@@ -1151,7 +1120,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Config-IOD
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Config-IOD>.
+Source repository is at L<https://github.com/perlancar/perl-Config-IOD>.
 
 =head1 BUGS
 
